.. meta::
    :description lang=en:
        Cloup is an extension pack for the popular Click Python library that adds
        option groups, constraints for group of parameters and the possibility
        to group the subcommands of a MultiCommand in multiple help sections.
    :keywords: python, click, option groups, help sections, mutually exclusive
    :google-site-verification: r5SEmg2wwCURBwKSrL_zQJEJbCVsScFhryur7zdFM3s

.. include:: ../README.rst
    :end-before: if-doc-stop-here

Table of contents
-----------------
.. toctree::
    :maxdepth: 2

    pages/usage
    autoapi/cloup/index
    pages/contributing
    pages/credits
    pages/changelog
